# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - SVGChart

    @copyright: 2011 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinMoin.action import cache
from MoinMoin import wikiutil
from SVGChartSupport import get_chart, get_dimensions

Dependencies = ["pages"]

# Parser support.

class Parser:

    "Format CSV-like data as an SVG chart."

    extensions = [".csv"]

    def __init__(self, raw, request, **kw):

        """
        Initialise the parser with the given 'raw' data, 'request' and any
        keyword arguments that may have been supplied.
        """

        self.raw = raw
        self.request = request
        self.data = [row.split() for row in raw.split("\n")]

        attrs, msg = wikiutil.parseAttributes(request, kw.get("format_args", ""))

        # The attributes returned from the formatting arguments are encoded like
        # strings.

        quotes = '"' + "'"
        self.xorigin = float((attrs.get("xorigin") or '0').strip(quotes))
        self.yorigin = float((attrs.get("yorigin") or '0').strip(quotes))
        width = (attrs.get("width") or '').strip(quotes) or None
        height = (attrs.get("height") or '').strip(quotes) or None
        self.width = width and int(width)
        self.height = height and int(height)

    def format(self, fmt):

        "Format a chart using the given formatter 'fmt'."

        request = self.request
        page = request.page
        _ = request.getText

        cache_key = cache.key(request, itemname=page.page_name, content="%s,%s,%s,%s,%s" % (
            self.width, self.height, self.xorigin, self.yorigin, self.raw))

        if not cache.exists(request, cache_key):
            width, height, chart = get_chart(self.data, self.width, self.height, self.xorigin, self.yorigin,
                styles_url="%s/%s/css/svgchart.css" % (request.cfg.url_prefix_static, request.theme.name))
            cache.put(request, cache_key, chart, content_type="image/svg+xml")
        else:
            width, height = get_dimensions(self.data, self.width, self.height, self.xorigin, self.yorigin)

        request.write(fmt.div(1, css_class="svgchart"))
        request.write(fmt.transclusion(1, data=cache.url(request, cache_key), width=width, height=height))
        request.write(fmt.text(_("SVG chart of CSV data.")))
        request.write(fmt.transclusion(0))
        request.write(fmt.div(0))

# vim: tabstop=4 expandtab shiftwidth=4
